MLOps for humans
================

omega-ml is the innovative Python-native MLOps platform that provides
a scalable development and runtime environment for your Data Products. Works
from laptop to cloud.

.. toctree::
   :maxdepth: 2

   quickstart/index
   guide/index
   admin/index
   devguide/index
   reference/index
   nb/index
   screenshots
   moreinfo


